#

    	possibilities
    		https://github.com/Happy-Coding-Clans/vue-easytable
    		https://github.com/Akryum/vue-progress-path
    		https://github.com/visma-meglerfront/sweet-modal-vue

    		https://github.com/antonreshetov/vue-unicons

    		https://github.com/vutran6853/vue3-chart-v2

    		https://github.com/kytta/vue-tinybox

    		effects:
    			[ ] https://www.vantajs.com/?effect=fog
    			[ ] https://marcbruederlin.github.io/particles.js/
    			[ ] https://www.kirilv.com/canvas-confetti/

    		exception handling:
    			https://rollbar.com/#

    		icons:
    			CC0:
    				https://3dicons.co/

    			editor:
    				https://studio.morflax.com/mix/

    			https://lukaszadam.com/illustrations

    			gumroad.com

    			https://www.vecteezy.com/vector-art/157814-furniture-icon-pack

    			https://github.com/webkul/vivid

    			https://heroicons.com/

    			https://github.com/Remix-Design/RemixIcon

    			https://tabler-icons.io/
    				https://github.com/tabler/tabler-icons/releases/tag/v2.32.0

    			companies:
    				https://github.com/devicons/devicon
    				https://simpleicons.org/?q=folder

    			https://github.com/tailwindlabs/heroicons

    			https://github.com/feathericons/feather

    			https://www.svgrepo.com/

    		relevant:
    			https://nodered.org/